# -*- coding: utf-8 -*-
# Part of Odoo. See LICENSE file for full copyright and licensing details.

from . import common
from . import test_frontend_buy_tickets
from . import test_website_event_sale_pricelist
